import{C as e,_ as p}from"./View.vue_vue_type_script_setup_true_lang-BKL24RPg.js";import{e as i,n,g as s,p as m}from"./jwt-decode.esm-BAacjh9V.js";import{u as a}from"./projectStore-Dd2Dlucx.js";import"./router-iojlVEw-.js";import"./ts.worker-Bvc4Bt-S.js";import"./fetch-DdAvxU6f.js";import"./tables-DT7drM2H.js";import"./string-BGv-YpdF.js";import"./SaveButton-DvgcGVeB.js";import"./ExclamationCircleOutlined-C23dqilt.js";import"./CrudView-D-YcFXPT.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-BubRvn_f.js";import"./constants-PfoXNq92.js";import"./url-D_3vogJH.js";import"./PhDotsThreeVertical.vue-wn2npLXK.js";import"./index-BUssfYSM.js";import"./asyncComputed-BmSm4oSd.js";import"./PhPencil.vue-C6CD3BMf.js";import"./useCodebaseEvents-BUgzFZJs.js";import"./contracts.generated-C62MAyib.js";import"./index-CaNtYc9K.js";import"./project-Bumi29an.js";import"./organizationSwitcher-BWfqfO2t.js";import"./organization-DzkN8-kj.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="3d94f7cd-1fad-4938-9294-98c2a9e73195",o._sentryDebugIdIdentifier="sentry-dbid-3d94f7cd-1fad-4938-9294-98c2a9e73195")}catch{}})();const z=i({__name:"EnvVars",setup(o){const r=a(),t=new e(r.projectId);return(d,c)=>(s(),n(p,{"env-var-repository":m(t),mode:"console"},null,8,["env-var-repository"]))}});export{z as default};
//# sourceMappingURL=EnvVars-72ThbOEA.js.map
